package net.wanji.opt.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * @author Kent HAN
 * @date 2023/2/9 8:38
 */
@Data
@NoArgsConstructor
@ApiModel(value = "RunningEvaluateMetricsDetailVO", description = "评价指标查询返回值")
public class RunningEvaluateMetricsDetailVO {
    private String crossId;
    @ApiModelProperty(value = "状态列表")
    private List<ProblemStatus> problemStatusList = Collections.emptyList();
    @ApiModelProperty(value = "问题方案列表")
    private List<ProblemScheme> schemeList = Collections.emptyList();
    @ApiModelProperty(value = "指标列表")
    private List<CrossMetrics> metricsList = Collections.emptyList();

    @NoArgsConstructor
    @Data
    public static class ProblemStatus {
        @ApiModelProperty(value = "路口状态 0正常 1 失衡  2 拥堵 3 溢出")
        private Integer status;

        @ApiModelProperty(value = "开始时间")
        @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "HH:mm", timezone = "GMT+8")
        private Date startTime;

        @ApiModelProperty(value = "结束时间")
        @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "HH:mm", timezone = "GMT+8")
        private Date endTime;

        @ApiModelProperty(value = "持续时长（分钟）")
        private Integer durationMinutes;
    }

    @NoArgsConstructor
    @Data
    public static class ProblemScheme {
        @ApiModelProperty(value = "方案ID")
        private Integer schemeId;

        @ApiModelProperty(value = "方案名称")
        private String schemeName;

        @ApiModelProperty(value = "开始时间")
        private String startTime;

        @ApiModelProperty(value = "结束时间")
        private String endTime;

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ProblemScheme that = (ProblemScheme) o;
            return Objects.equals(schemeName, that.schemeName) &&
                    Objects.equals(startTime, that.startTime) &&
                    Objects.equals(endTime, that.endTime);
        }

        @Override
        public int hashCode() {
            return Objects.hash(schemeName, startTime, endTime);
        }
    }

    @NoArgsConstructor
    @Data
    public static class CrossMetrics {
        @ApiModelProperty(value = "时间")
        private String metricTime;

        @ApiModelProperty(value = "流量")
        private Integer flow;

        @ApiModelProperty(value = "平均速度（km/h）")
        private Double speed;

        @ApiModelProperty(value = "通行能力")
        private Integer capacity;

        @ApiModelProperty(value = "饱和度")
        private Double sturation;

        @ApiModelProperty(value = "平均停车次数")
        private Double stopTimes;

        @ApiModelProperty(value = "平均延误（秒）")
        private Integer delayTime ;

        @ApiModelProperty(value = "溢流率")
        private Double effusionRate ;

        @ApiModelProperty(value = "绿灯空放时长")
        private Integer emptyPhase ;

    }
}
